aboutsummaryrefslogtreecommitdiff
path: root/bpkg/fetch.hxx
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2018-03-03 18:50:18 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2018-03-05 12:26:23 +0300
commit0d3525d80fbeee78ae49384f2d722de20127a040 (patch)
tree6e60603e396c7cd0e781806782dfa31cb13980cf /bpkg/fetch.hxx
parent87841c9288561a3ad580ae23bb288ff3d3d39719 (diff)
Rename bpkg repository type to pkg
Diffstat (limited to 'bpkg/fetch.hxx')
-rw-r--r--bpkg/fetch.hxx40
1 files changed, 20 insertions, 20 deletions
diff --git a/bpkg/fetch.hxx b/bpkg/fetch.hxx
index 659e019..fc6b763 100644
--- a/bpkg/fetch.hxx
+++ b/bpkg/fetch.hxx
@@ -16,35 +16,35 @@
namespace bpkg
{
// Repository type bpkg (fetch-bpkg.cxx).
//
- bpkg_repository_manifests
- bpkg_fetch_repositories (const dir_path&, bool ignore_unknown);
+ pkg_repository_manifests
+ pkg_fetch_repositories (const dir_path&, bool ignore_unknown);
- pair<bpkg_repository_manifests, string /* checksum */>
- bpkg_fetch_repositories (const common_options&,
- const repository_location&,
- bool ignore_unknown);
+ pair<pkg_repository_manifests, string /* checksum */>
+ pkg_fetch_repositories (const common_options&,
+ const repository_location&,
+ bool ignore_unknown);
- bpkg_package_manifests
- bpkg_fetch_packages (const dir_path&, bool ignore_unknown);
+ pkg_package_manifests
+ pkg_fetch_packages (const dir_path&, bool ignore_unknown);
- pair<bpkg_package_manifests, string /* checksum */>
- bpkg_fetch_packages (const common_options&,
- const repository_location&,
- bool ignore_unknown);
+ pair<pkg_package_manifests, string /* checksum */>
+ pkg_fetch_packages (const common_options&,
+ const repository_location&,
+ bool ignore_unknown);
signature_manifest
- bpkg_fetch_signature (const common_options&,
- const repository_location&,
- bool ignore_unknown);
+ pkg_fetch_signature (const common_options&,
+ const repository_location&,
+ bool ignore_unknown);
path
- bpkg_fetch_archive (const common_options&,
- const repository_location&,
- const path& archive,
- const dir_path& destdir);
+ pkg_fetch_archive (const common_options&,
+ const repository_location&,
+ const path& archive,
+ const dir_path& destdir);
// Repository type git (fetch-git.cxx).
//
@@ -16,35 +16,35 @@
namespace bpkg
{
- // Repository type bpkg (fetch-bpkg.cxx).
+ // Repository type pkg (fetch-pkg.cxx).
//